summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/ownedcodeblock.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/ownedcodeblock.h')
-rw-r--r--umbrello/umbrello/ownedcodeblock.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/umbrello/umbrello/ownedcodeblock.h b/umbrello/umbrello/ownedcodeblock.h
index 0a71f50c..130bd4dd 100644
--- a/umbrello/umbrello/ownedcodeblock.h
+++ b/umbrello/umbrello/ownedcodeblock.h
@@ -29,12 +29,13 @@ class UMLObject;
/**
* class OwnedCodeBlock
* Describes any codeblock which is 'owned' by a UMLobject of some sort and should
* be in sync with that parent.
*/
-class OwnedCodeBlock : virtual public QObject
+class OwnedCodeBlock : virtual public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
// Constructors/Destructors
@@ -43,7 +44,7 @@ public:
/**
* Constructor
*/
- OwnedCodeBlock ( UMLObject * parent );
+ OwnedCodeBlock ( UMLObject * tqparent );
/**
* Empty Destructor
@@ -55,7 +56,7 @@ public:
*/
UMLObject * getParentObject ( );
// get the parent code document of this code block
virtual CodeDocument * getParentDocument ( ) = 0;
protected:
@@ -87,7 +88,7 @@ protected:
private:
- void initFields ( UMLObject * parent );
+ void initFields ( UMLObject * tqparent );
UMLObject * m_parentObject;
@@ -29,12 +29,13 @@ class UMLObject;
* class OwnedCodeBlock
* Describes any codeblock which is 'owned' by a UMLobject of some sort and should
- * be in sync with that parent.
+ * be in sync with that tqparent.
*/
@@ -55,7 +56,7 @@ public:
*/
UMLObject * getParentObject ( );
- // get the parent code document of this code block
+ // get the tqparent code document of this code block
virtual CodeDocument * getParentDocument ( ) = 0;
protected: